@@ -46,7 +46,7 @@ func NewDefaultConfig() *Config {
 	return &Config{
 		TTL: env.GetOrDefaultInt(EnvTTL, 300),
 		// INWX has rather unstable propagation delays, thus using a larger default value
-		PropagationTimeout: env.GetOrDefaultSecond(EnvPropagationTimeout, 360*time.Second),
+		PropagationTimeout: env.GetOrDefaultSecond(EnvPropagationTimeout, 6*time.Minute),
 		PollingInterval:    env.GetOrDefaultSecond(EnvPollingInterval, dns01.DefaultPollingInterval),
 		Sandbox:            env.GetOrDefaultBool(EnvSandbox, false),
 	}
@@ -178,12 +178,14 @@ func (d *DNSProvider) CleanUp(domain, token, keyAuth string) error {
 	}
 
 	var recordID int
+
 	for _, record := range response.Records {
 		if record.Content != info.Value {
 			continue
 		}
 
 		recordID = record.ID
+
 		break
 	}
 
