@@ -1,10 +1,8 @@
 package namecheap
 
 import (
-	"net/http"
 	"net/http/httptest"
 	"testing"
-	"time"
 
 	"github.com/go-acme/lego/v4/platform/tester/servermock"
 	"github.com/stretchr/testify/assert"
@@ -154,6 +152,7 @@ func Test_newPseudoRecord_domainSplit(t *testing.T) {
 	for _, test := range tests {
 		t.Run(test.domain, func(t *testing.T) {
 			valid := true
+
 			ch, err := newPseudoRecord(test.domain, "")
 			if err != nil {
 				valid = false
@@ -179,11 +178,11 @@ func Test_newPseudoRecord_domainSplit(t *testing.T) {
 func mockBuilder() *servermock.Builder[*DNSProvider] {
 	return servermock.NewBuilder(func(server *httptest.Server) (*DNSProvider, error) {
 		config := NewDefaultConfig()
+		config.HTTPClient = server.Client()
 		config.BaseURL = server.URL
 		config.APIUser = envTestUser
 		config.APIKey = envTestKey
 		config.ClientIP = envTestClientIP
-		config.HTTPClient = &http.Client{Timeout: 60 * time.Second}
 
 		return NewDNSProviderConfig(config)
 	})
